# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litematrimony/profile/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litematrimony\\Profile\\": "packages/litematrimony/profile/src",
            "Litematrimony\\Profile\\Seeders\\": "packages/litematrimony/profile/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litematrimony\Profile\Providers\ProfileServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Profile'  => Litematrimony\Profile\Facades\Profile::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litematrimony\\Profile\\Seeders\\ProfileTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litematrimony\Profile\Providers\ProfileServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litematrimony\Profile\Providers\ProfileServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litematrimony\Profile\Providers\ProfileServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/profile/{modulename}

**User**

    http://path-to-route-folder/user/profile/{modulename}

**Public**

    http://path-to-route-folder/profiles


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/profile/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/profile/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/profile/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/profile/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/profile/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/profile/{modulename}/{slug}
    METHOD: GET